@@ -1,4 +1,4 @@
-// Copyright (C) 2016 and later: Unicode, Inc. and others.
+// © 2016 and later: Unicode, Inc. and others.
 // License & terms of use: http://www.unicode.org/copyright.html
 /********************************************************************
  * COPYRIGHT: 
@@ -55,7 +55,7 @@ void PluralFormatTest::pluralFormatBasicTest(/*char *par*/)
     PluralFormat* plFmt[8];
     Locale        locale = Locale::getDefault();
     UnicodeString otherPattern = UnicodeString("other{#}");
-    UnicodeString message=UnicodeString("ERROR: PluralFormat basic test");
+    UnicodeString message=UnicodeString("PluralFormat basic test");
 
     // ========= Test constructors
     logln(" Testing PluralFormat constructors ...");
@@ -82,8 +82,8 @@ void PluralFormatTest::pluralFormatBasicTest(/*char *par*/)
     
     for (int32_t i=0; i< 8; ++i) {
         if (U_SUCCESS(status[i])) {
-            numberFormatTest(plFmt[i], numFmt, 1, 12, NULL, NULL, FALSE, &message);
-            numberFormatTest(plFmt[i], numFmt, 100, 112, NULL, NULL, FALSE, &message);
+            numberFormatTest(plFmt[i], numFmt, 1, 12, nullptr, nullptr, false, &message);
+            numberFormatTest(plFmt[i], numFmt, 100, 112, nullptr, nullptr, false, &message);
         }
         else {
             dataerrln("ERROR: PluralFormat constructor failed!");
@@ -98,7 +98,7 @@ void PluralFormatTest::pluralFormatBasicTest(/*char *par*/)
     plFmt[1]= new PluralFormat(locale, status[1]);
     if ( U_SUCCESS(status[0]) && U_SUCCESS(status[1]) ) {
         *plFmt[1] = *plFmt[0];
-        if (plFmt[1]!=NULL) {
+        if (plFmt[1]!=nullptr) {
             if ( *plFmt[1] != *plFmt[0] ) {
                 errln("ERROR:  clone plural format test failed!");
             }
@@ -113,7 +113,7 @@ void PluralFormatTest::pluralFormatBasicTest(/*char *par*/)
     plFmt[0]= new PluralFormat(locale, status[0]);
     if ( U_SUCCESS(status[0]) ) {
         *plFmt[1] = *plFmt[0];
-        if (plFmt[1]!=NULL) {
+        if (plFmt[1]!=nullptr) {
             if ( *plFmt[1] != *plFmt[0] ) {
                 errln("ERROR:  assignment operator test failed!");
             }
@@ -124,9 +124,9 @@ void PluralFormatTest::pluralFormatBasicTest(/*char *par*/)
     }
 
     if ( U_SUCCESS(status[1]) ) {
-        plFmt[2] = (PluralFormat*) plFmt[1]->clone();
+        plFmt[2] = plFmt[1]->clone();
 
-        if (plFmt[1]!=NULL) {
+        if (plFmt[1]!=nullptr) {
             if ( *plFmt[1] != *plFmt[2] ) {
                 errln("ERROR:  clone function test failed!");
             }
@@ -194,9 +194,9 @@ void PluralFormatTest::pluralFormatUnitTest(/*char *par*/)
 
     UErrorCode status = U_ZERO_ERROR;
     UnicodeString oddAndEvenRule = UNICODE_STRING_SIMPLE("odd: n mod 2 is 1");
-    PluralRules*  plRules = PluralRules::createRules(oddAndEvenRule, status);
+    LocalPointer<PluralRules>plRules(PluralRules::createRules(oddAndEvenRule, status));
     if (U_FAILURE(status)) {
-        dataerrln("ERROR:  create PluralRules instance failed in unit tests.- exitting");
+        dataerrln("ERROR:  create PluralRules instance failed in unit tests.- exiting");
         return;
     }
     
@@ -207,7 +207,7 @@ void PluralFormatTest::pluralFormatUnitTest(/*char *par*/)
         
         PluralFormat plFmt=PluralFormat(*plRules, status);
         if (U_FAILURE(status)) {
-            dataerrln("ERROR:  PluralFormat constructor failed in unit tests.- exitting");
+            dataerrln("ERROR:  PluralFormat constructor failed in unit tests.- exiting");
             return;
         }
         plFmt.applyPattern(checkSyntaxtData[i], status);
@@ -221,9 +221,9 @@ void PluralFormatTest::pluralFormatUnitTest(/*char *par*/)
     // ======= Test applying various pattern
     logln("Testing various patterns");
     status = U_ZERO_ERROR;
-    UBool overwrite[PLURAL_PATTERN_DATA] = {FALSE, FALSE, TRUE, TRUE};
+    UBool overwrite[PLURAL_PATTERN_DATA] = {false, false, true, true};
     
-    NumberFormat *numFmt = NumberFormat::createInstance(status);
+    LocalPointer<NumberFormat> numFmt(NumberFormat::createInstance(status));
     UnicodeString message=UnicodeString("ERROR: PluralFormat tests various pattern ...");
     if (U_FAILURE(status)) {
         dataerrln("ERROR: Could not create NumberFormat instance with default locale ");
@@ -232,7 +232,7 @@ void PluralFormatTest::pluralFormatUnitTest(/*char *par*/)
         status = U_ZERO_ERROR;
         PluralFormat plFmt=PluralFormat(*plRules, status);
         if (U_FAILURE(status)) {
-            dataerrln("ERROR:  PluralFormat constructor failed in unit tests.- exitting");
+            dataerrln("ERROR:  PluralFormat constructor failed in unit tests.- exiting");
             return;
         }
         plFmt.applyPattern(patternTestData[i], status);
@@ -240,37 +240,33 @@ void PluralFormatTest::pluralFormatUnitTest(/*char *par*/)
             errln("ERROR:  PluralFormat failed to apply pattern- "+patternTestData[i]);
             continue;
         }
-        numberFormatTest(&plFmt, numFmt, 1, 10, (UnicodeString *)&patternOddTestResult[i], 
-                         (UnicodeString *)&patternEvenTestResult[i], overwrite[i], &message);
+        numberFormatTest(&plFmt, numFmt.getAlias(), 1, 10, dynamic_cast<UnicodeString *>(&patternOddTestResult[i]), 
+                         dynamic_cast<UnicodeString *>(&patternEvenTestResult[i]), overwrite[i], &message);
     }
-    delete plRules;
-    delete numFmt;
     
     // ======= Test set locale
     status = U_ZERO_ERROR;
-    plRules = PluralRules::createRules(UNICODE_STRING_SIMPLE("odd: n mod 2 is 1"), status);  
+    plRules.adoptInstead(PluralRules::createRules(UNICODE_STRING_SIMPLE("odd: n mod 2 is 1"), status));  
     PluralFormat pluralFmt = PluralFormat(*plRules, status);
     if (U_FAILURE(status)) {
-        dataerrln("ERROR: Could not create PluralFormat instance in setLocale() test - exitting. ");
-        delete plRules;
+        dataerrln("ERROR: Could not create PluralFormat instance in setLocale() test - exiting. ");
         return;
     }
     pluralFmt.applyPattern(UNICODE_STRING_SIMPLE("odd{odd} other{even}"), status);
     pluralFmt.setLocale(Locale::getEnglish(), status);
     if (U_FAILURE(status)) {
         dataerrln("ERROR: Could not setLocale() with English locale ");
-        delete plRules;
         return;
     }
     message = UNICODE_STRING_SIMPLE("Error set locale: pattern is not reset!");
     
     // Check that pattern gets deleted.
     logln("\n Test setLocale() ..\n");
-    numFmt = NumberFormat::createInstance(Locale::getEnglish(), status);
+    numFmt.adoptInstead(NumberFormat::createInstance(Locale::getEnglish(), status));
     if (U_FAILURE(status)) {
         dataerrln("ERROR: Could not create NumberFormat instance with English locale ");
     }
-    numberFormatTest(&pluralFmt, numFmt, 5, 5, NULL, NULL, FALSE, &message);
+    numberFormatTest(&pluralFmt, numFmt.getAlias(), 5, 5, nullptr, nullptr, false, &message);
     pluralFmt.applyPattern(UNICODE_STRING_SIMPLE("odd__{odd} other{even}"), status);
     if (pluralFmt.format((int32_t)1, status) != UNICODE_STRING_SIMPLE("even")) {
         errln("SetLocale should reset rules but did not.");
@@ -302,9 +298,6 @@ void PluralFormatTest::pluralFormatUnitTest(/*char *par*/)
     if (pluralFmt != dupPFmt) {
         errln("Failed in PluralFormat copy constructor or == operator");
     }
-    
-    delete plRules;
-    delete numFmt;
 }
 
 
@@ -389,9 +382,10 @@ PluralFormatTest::pluralFormatLocaleTest(/*char *par*/)
     pluralResults[0]= PFT_FEW;
     for (int32_t i=1; i<20; ++i) {
         pluralResults[i] = PFT_FEW; // note override after loop
-        pluralResults[100+i] = PFT_FEW;
+        pluralResults[100+i] = PFT_FEW; // note override after loop
     }
     pluralResults[1]= PFT_ONE;
+    pluralResults[100]= PFT_OTHER;
     helperTestResults(singularZeroSomeLocales, 1, testPattern, pluralResults);
     
     // ======== Test Special 12/19.
@@ -541,7 +535,7 @@ PluralFormatTest::pluralFormatLocaleTest(/*char *par*/)
 }
 
 void
-PluralFormatTest::pluralFormatExtendedTest(void) {
+PluralFormatTest::pluralFormatExtendedTest() {
   const char *targets[] = {
     "There are no widgets.",
     "There is one widget.",
@@ -564,7 +558,7 @@ PluralFormatTest::pluralFormatExtendedTest(void) {
   UErrorCode status = U_ZERO_ERROR;
   UnicodeString fmtString(fmt, -1, US_INV);
   PluralFormat pf(Locale::getEnglish(), fmtString, status);
-  MessageFormat mf(UNICODE_STRING_SIMPLE("{0,plural,").append(fmtString).append((UChar)0x7d /* '}' */),
+  MessageFormat mf(UNICODE_STRING_SIMPLE("{0,plural,").append(fmtString).append((char16_t)0x7d /* '}' */),
                    Locale::getEnglish(), status);
   Formattable args;
   FieldPosition ignore;
@@ -605,7 +599,7 @@ PluralFormatTest::pluralFormatExtendedTest(void) {
 }
 
 void
-PluralFormatTest::pluralFormatExtendedParseTest(void) {
+PluralFormatTest::pluralFormatExtendedParseTest() {
   const char *failures[] = {
     "offset:1..0 =0 {Foo}",
     "offset:1.0 {Foo}",
@@ -626,25 +620,25 @@ PluralFormatTest::pluralFormatExtendedParseTest(void) {
 }
 
 void
-PluralFormatTest::ordinalFormatTest(void) {
+PluralFormatTest::ordinalFormatTest() {
     IcuTestErrorCode errorCode(*this, "ordinalFormatTest");
     UnicodeString pattern("one{#st file}two{#nd file}few{#rd file}other{#th file}");
     PluralFormat pf(Locale::getEnglish(), UPLURAL_TYPE_ORDINAL, pattern, errorCode);
-    if (errorCode.logDataIfFailureAndReset("PluralFormat(en, UPLURAL_TYPE_ORDINAL, pattern) failed")) {
+    if (errorCode.errDataIfFailureAndReset("PluralFormat(en, UPLURAL_TYPE_ORDINAL, pattern) failed")) {
       return;
     }
     UnicodeString result = pf.format((int32_t)321, errorCode);
-    if (!errorCode.logIfFailureAndReset("PluralFormat.format(321) failed") &&
+    if (!errorCode.errIfFailureAndReset("PluralFormat.format(321) failed") &&
         result != UNICODE_STRING_SIMPLE("321st file")) {
       errln(UnicodeString("PluralFormat.format(321) wrong result string: ") + result);
     }
     result = pf.format((int32_t)22, errorCode);
-    if (!errorCode.logIfFailureAndReset("PluralFormat.format(22) failed") &&
+    if (!errorCode.errIfFailureAndReset("PluralFormat.format(22) failed") &&
         result != UNICODE_STRING_SIMPLE("22nd file")) {
       errln(UnicodeString("PluralFormat.format(22) wrong result string: ") + result);
     }
     result = pf.format((int32_t)3, errorCode);
-    if (!errorCode.logIfFailureAndReset("PluralFormat.format(3) failed") &&
+    if (!errorCode.errIfFailureAndReset("PluralFormat.format(3) failed") &&
         result != UNICODE_STRING_SIMPLE("3rd file")) {
       errln(UnicodeString("PluralFormat.format(3) wrong result string: ") + result);
     }
@@ -652,16 +646,16 @@ PluralFormatTest::ordinalFormatTest(void) {
     // Code coverage: Use the other new-for-UPluralType constructor as well.
     PluralFormat pf2(Locale::getEnglish(), UPLURAL_TYPE_ORDINAL, errorCode);
     pf2.applyPattern(pattern, errorCode);
-    if (errorCode.logIfFailureAndReset("PluralFormat(en, UPLURAL_TYPE_ORDINAL, pattern) failed")) {
+    if (errorCode.errIfFailureAndReset("PluralFormat(en, UPLURAL_TYPE_ORDINAL, pattern) failed")) {
       return;
     }
     result = pf2.format((int32_t)456, errorCode);
-    if (!errorCode.logIfFailureAndReset("PluralFormat.format(456) failed") &&
+    if (!errorCode.errIfFailureAndReset("PluralFormat.format(456) failed") &&
         result != UNICODE_STRING_SIMPLE("456th file")) {
       errln(UnicodeString("PluralFormat.format(456) wrong result string: ") + result);
     }
     result = pf2.format((int32_t)111, errorCode);
-    if (!errorCode.logIfFailureAndReset("PluralFormat.format(111) failed") &&
+    if (!errorCode.errIfFailureAndReset("PluralFormat.format(111) failed") &&
         result != UNICODE_STRING_SIMPLE("111th file")) {
       errln(UnicodeString("PluralFormat.format(111) wrong result string: ") + result);
     }
@@ -672,20 +666,20 @@ PluralFormatTest::TestDecimals() {
     IcuTestErrorCode errorCode(*this, "TestDecimals");
     // Simple number replacement.
     PluralFormat pf(Locale::getEnglish(), "one{one meter}other{# meters}", errorCode);
-    assertEquals("simple format(1)", "one meter", pf.format((int32_t)1, errorCode), TRUE);
-    assertEquals("simple format(1.5)", "1.5 meters", pf.format(1.5, errorCode), TRUE);
+    assertEquals("simple format(1)", "one meter", pf.format((int32_t)1, errorCode), true);
+    assertEquals("simple format(1.5)", "1.5 meters", pf.format(1.5, errorCode), true);
     PluralFormat pf2(Locale::getEnglish(),
             "offset:1 one{another meter}other{another # meters}", errorCode);
     DecimalFormat df("0.0", new DecimalFormatSymbols(Locale::getEnglish(), errorCode), errorCode);
     pf2.setNumberFormat(&df, errorCode);
-    assertEquals("offset-decimals format(1)", "another 0.0 meters", pf2.format((int32_t)1, errorCode), TRUE);
-    assertEquals("offset-decimals format(2)", "another 1.0 meters", pf2.format((int32_t)2, errorCode), TRUE);
-    assertEquals("offset-decimals format(2.5)", "another 1.5 meters", pf2.format(2.5, errorCode), TRUE);
+    assertEquals("offset-decimals format(1)", "another 0.0 meters", pf2.format((int32_t)1, errorCode), true);
+    assertEquals("offset-decimals format(2)", "another 1.0 meters", pf2.format((int32_t)2, errorCode), true);
+    assertEquals("offset-decimals format(2.5)", "another 1.5 meters", pf2.format(2.5, errorCode), true);
     errorCode.reset();
 }
 
 void
-PluralFormatTest::numberFormatTest(PluralFormat* plFmt, 
+PluralFormatTest::numberFormatTest(PluralFormat* plFmt,
                                    NumberFormat *numFmt,
                                    int32_t start,
                                    int32_t end,
@@ -695,8 +689,8 @@ PluralFormatTest::numberFormatTest(PluralFormat* plFmt,
                                    UnicodeString *message) {
     UErrorCode status = U_ZERO_ERROR;
     
-    if ( (plFmt==NULL) || (numFmt==NULL) ) {
-        dataerrln("ERROR: Could not create PluralFormat or NumberFormat - exitting");
+    if ( (plFmt==nullptr) || (numFmt==nullptr) ) {
+        dataerrln("ERROR: Could not create PluralFormat or NumberFormat - exiting");
         return;
     }
     UnicodeString plResult, numResult ;
@@ -705,7 +699,7 @@ PluralFormatTest::numberFormatTest(PluralFormat* plFmt,
         numResult.remove();
         numResult = numFmt->format(i, numResult);
         plResult = plFmt->format(i, status);
-        if ((numOddAppendStr!= NULL)&&(numEvenAppendStr!=NULL)) {
+        if ((numOddAppendStr!= nullptr)&&(numEvenAppendStr!=nullptr)) {
             if (overwrite) {
                 if (i&1) {
                     numResult = *numOddAppendStr;
@@ -723,12 +717,15 @@ PluralFormatTest::numberFormatTest(PluralFormat* plFmt,
                 }
             }
         }
-        if ( (numResult!=plResult) || U_FAILURE(status) ) {
-            if ( message == NULL ) {
+        if (U_FAILURE(status)) {
+            assertSuccess(*message + " in numberFormatTest", status);
+        }
+        if (numResult!=plResult) {
+            if ( message == nullptr ) {
                 errln("ERROR: Unexpected plural format - got:"+plResult+ UnicodeString("  expecting:")+numResult);
             }
             else {
-                errln( *message+UnicodeString("  got:")+plResult+UnicodeString("  expecting:")+numResult);
+                assertEquals(*message + " in numberFormatTest", numResult, plResult);
             }
         }
     }
