@@ -1,4 +1,4 @@
-// Copyright (C) 2016 and later: Unicode, Inc. and others.
+// © 2016 and later: Unicode, Inc. and others.
 // License & terms of use: http://www.unicode.org/copyright.html
 /*
 *******************************************************************************
@@ -18,7 +18,7 @@
 class UCTItem : public SharedObject {
   public:
     char *value;
-    UCTItem(const char *x) : value(NULL) { 
+    UCTItem(const char *x) : value(nullptr) { 
         value = uprv_strdup(x);
     }
     virtual ~UCTItem() {
@@ -34,20 +34,20 @@ U_NAMESPACE_BEGIN
 template<> U_EXPORT
 const UCTItem *LocaleCacheKey<UCTItem>::createObject(
         const void *context, UErrorCode &status) const {
-    const UnifiedCache *cacheContext = (const UnifiedCache *) context;
+    const UnifiedCache *cacheContext = static_cast<const UnifiedCache *>(context);
     if (uprv_strcmp(fLoc.getName(), "zh") == 0) {
         status = U_MISSING_RESOURCE_ERROR;
-        return NULL;
+        return nullptr;
     }
     if (uprv_strcmp(fLoc.getLanguage(), fLoc.getName()) != 0) {
-        const UCTItem *item = NULL;
-        if (cacheContext == NULL) {
+        const UCTItem *item = nullptr;
+        if (cacheContext == nullptr) {
             UnifiedCache::getByLocale(fLoc.getLanguage(), item, status);
         } else {
             cacheContext->get(LocaleCacheKey<UCTItem>(fLoc.getLanguage()), item, status);
         }
         if (U_FAILURE(status)) {
-            return NULL;
+            return nullptr;
         }
         return item;
     }
@@ -59,7 +59,7 @@ const UCTItem *LocaleCacheKey<UCTItem>::createObject(
 template<> U_EXPORT
 const UCTItem2 *LocaleCacheKey<UCTItem2>::createObject(
         const void * /*unused*/, UErrorCode & /*status*/) const {
-    return NULL;
+    return nullptr;
 }
 
 U_NAMESPACE_END
@@ -69,7 +69,7 @@ class UnifiedCacheTest : public IntlTest {
 public:
     UnifiedCacheTest() {
     }
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par=0);
+    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par=0) override;
 private:
     void TestEvictionPolicy();
     void TestBounded();
@@ -122,15 +122,15 @@ void UnifiedCacheTest::TestEvictionPolicy() {
     UnifiedCache cache(status);
     assertSuccess("", status);
 
-    // Don't allow unused entries to exeed more than 100% of in use entries.
+    // Don't allow unused entries to exceed more than 100% of in use entries.
     cache.setEvictionPolicy(0, 100, status);
 
     static const char *locales[] = {
             "1", "2", "3", "4", "5", "6", "7", "8", "9", "10",
             "11", "12", "13", "14", "15", "16", "17", "18", "19", "20"};
 
-    const UCTItem *usedReferences[] = {NULL, NULL, NULL, NULL, NULL};
-    const UCTItem *unusedReference = NULL;
+    const UCTItem *usedReferences[] = {nullptr, nullptr, nullptr, nullptr, nullptr};
+    const UCTItem *unusedReference = nullptr;
 
     // Add 5 in-use entries
     for (int32_t i = 0; i < UPRV_LENGTHOF(usedReferences); i++) {
@@ -152,9 +152,9 @@ void UnifiedCacheTest::TestEvictionPolicy() {
     }
     unusedReference->removeRef();
 
-    // unused count not to exeed in use count
-    assertEquals("", UPRV_LENGTHOF(usedReferences), cache.unusedCount());
-    assertEquals("", 2*UPRV_LENGTHOF(usedReferences), cache.keyCount());
+    // unused count not to exceed in use count
+    assertEquals("T1", UPRV_LENGTHOF(usedReferences), cache.unusedCount());
+    assertEquals("T2", 2*UPRV_LENGTHOF(usedReferences), cache.keyCount());
 
     // Free up those used entries.
     for (int32_t i = 0; i < UPRV_LENGTHOF(usedReferences); i++) {
@@ -162,9 +162,9 @@ void UnifiedCacheTest::TestEvictionPolicy() {
     }
 
     // This should free up all cache items
-    assertEquals("", 0, cache.keyCount());
+    assertEquals("T3", 0, cache.keyCount());
 
-    assertSuccess("", status);
+    assertSuccess("T4", status);
 }
 
 
@@ -181,7 +181,7 @@ void UnifiedCacheTest::TestBounded() {
     // complete control over it. Real clients should never ever create
     // their own cache!
     UnifiedCache cache(status);
-    assertSuccess("", status);
+    assertSuccess("T0", status);
 
     // Maximum unused count is 3.
     cache.setEvictionPolicy(3, 0, status);
@@ -195,28 +195,28 @@ void UnifiedCacheTest::TestBounded() {
     // We first add 5 key-value pairs with two distinct values, "en" and "fr"
     // keeping all those references.
 
-    const UCTItem *en = NULL;
-    const UCTItem *enGb = NULL;
-    const UCTItem *enUs = NULL;
-    const UCTItem *fr = NULL;
-    const UCTItem *frFr = NULL;
+    const UCTItem *en = nullptr;
+    const UCTItem *enGb = nullptr;
+    const UCTItem *enUs = nullptr;
+    const UCTItem *fr = nullptr;
+    const UCTItem *frFr = nullptr;
     cache.get(LocaleCacheKey<UCTItem>("en_US"), &cache, enUs, status);
     cache.get(LocaleCacheKey<UCTItem>("en"), &cache, en, status);
-    assertEquals("", 1, cache.unusedCount());
+    assertEquals("T1", 1, cache.unusedCount());
     cache.get(LocaleCacheKey<UCTItem>("en_GB"), &cache, enGb, status);
     cache.get(LocaleCacheKey<UCTItem>("fr_FR"), &cache, frFr, status);
     cache.get(LocaleCacheKey<UCTItem>("fr"), &cache, fr, status);
 
     // Client holds two unique references, "en" and "fr" the other three
     // entries are eligible for eviction. 
-    assertEquals("", 3, cache.unusedCount());
-    assertEquals("", 5, cache.keyCount());
+    assertEquals("T2", 3, cache.unusedCount());
+    assertEquals("T3", 5, cache.keyCount());
 
     // Exercise cache more but don't hold the references except for
     // the last one. At the end of this, we will hold references to one
     // additional distinct value, so we will have references to 3 distinct
     // values.
-    const UCTItem *throwAway = NULL;
+    const UCTItem *throwAway = nullptr;
     cache.get(LocaleCacheKey<UCTItem>("zn_AA"), &cache, throwAway, status);
     cache.get(LocaleCacheKey<UCTItem>("sr_AA"), &cache, throwAway, status);
     cache.get(LocaleCacheKey<UCTItem>("de_AU"), &cache, throwAway, status);
@@ -227,49 +227,49 @@ void UnifiedCacheTest::TestBounded() {
     // Client holds three unique references, "en", "fr", "de" although we
     // could have a total of 8 entries in the cache maxUnusedCount == 3
     // so we have only 6 entries.
-    assertEquals("", 3, cache.unusedCount());
-    assertEquals("", 6, cache.keyCount());
+    assertEquals("T4", 3, cache.unusedCount());
+    assertEquals("T5", 6, cache.keyCount());
 
     // For all the references we have, cache must continue to return
     // those same references (#2)
 
     cache.get(LocaleCacheKey<UCTItem>("en"), &cache, throwAway, status);
     if (throwAway != en) {
-        errln("Expected en to resolve to the same object.");
+        errln("T6: Expected en to resolve to the same object.");
     }
     cache.get(LocaleCacheKey<UCTItem>("en_US"), &cache, throwAway, status);
     if (throwAway != enUs) {
-        errln("Expected enUs to resolve to the same object.");
+        errln("T7: Expected enUs to resolve to the same object.");
     }
     cache.get(LocaleCacheKey<UCTItem>("en_GB"), &cache, throwAway, status);
     if (throwAway != enGb) {
-        errln("Expected enGb to resolve to the same object.");
+        errln("T8: Expected enGb to resolve to the same object.");
     }
     cache.get(LocaleCacheKey<UCTItem>("fr_FR"), &cache, throwAway, status);
     if (throwAway != frFr) {
-        errln("Expected frFr to resolve to the same object.");
+        errln("T9: Expected frFr to resolve to the same object.");
     }
     cache.get(LocaleCacheKey<UCTItem>("fr_FR"), &cache, throwAway, status);
     cache.get(LocaleCacheKey<UCTItem>("fr"), &cache, throwAway, status);
     if (throwAway != fr) {
-        errln("Expected fr to resolve to the same object.");
+        errln("T10: Expected fr to resolve to the same object.");
     }
     cache.get(LocaleCacheKey<UCTItem>("de_AU"), &cache, throwAway, status);
     if (throwAway != deAu) {
-        errln("Expected deAu to resolve to the same object.");
+        errln("T11: Expected deAu to resolve to the same object.");
     }
 
-    assertEquals("", 3, cache.unusedCount());
-    assertEquals("", 6, cache.keyCount());
+    assertEquals("T12", 3, cache.unusedCount());
+    assertEquals("T13", 6, cache.keyCount());
 
     // Now we hold a references to two more distinct values. Cache size 
     // should grow to 8.
-    const UCTItem *es = NULL;
-    const UCTItem *ru = NULL;
+    const UCTItem *es = nullptr;
+    const UCTItem *ru = nullptr;
     cache.get(LocaleCacheKey<UCTItem>("es"), &cache, es, status);
     cache.get(LocaleCacheKey<UCTItem>("ru"), &cache, ru, status);
-    assertEquals("", 3, cache.unusedCount());
-    assertEquals("", 8, cache.keyCount());
+    assertEquals("T14", 3, cache.unusedCount());
+    assertEquals("T15", 8, cache.keyCount());
 
     // Now release all the references we hold except for
     // es, ru, and en
@@ -284,13 +284,13 @@ void UnifiedCacheTest::TestBounded() {
     SharedObject::clearPtr(throwAway);
 
     // Size of cache should magically drop to 3.
-    assertEquals("", 3, cache.unusedCount());
-    assertEquals("", 3, cache.keyCount());
+    assertEquals("T16", 3, cache.unusedCount());
+    assertEquals("T17", 3, cache.keyCount());
 
     // Be sure nothing happens setting the eviction policy in the middle of
     // a run.
     cache.setEvictionPolicy(3, 0, status);
-    assertSuccess("", status);
+    assertSuccess("T18", status);
     
 }
 
@@ -300,18 +300,18 @@ void UnifiedCacheTest::TestBasic() {
     assertSuccess("", status);
     cache->flush();
     int32_t baseCount = cache->keyCount();
-    const UCTItem *en = NULL;
-    const UCTItem *enGb = NULL;
-    const UCTItem *enGb2 = NULL;
-    const UCTItem *enUs = NULL;
-    const UCTItem *fr = NULL;
-    const UCTItem *frFr = NULL;
+    const UCTItem *en = nullptr;
+    const UCTItem *enGb = nullptr;
+    const UCTItem *enGb2 = nullptr;
+    const UCTItem *enUs = nullptr;
+    const UCTItem *fr = nullptr;
+    const UCTItem *frFr = nullptr;
     cache->get(LocaleCacheKey<UCTItem>("en"), en, status);
     cache->get(LocaleCacheKey<UCTItem>("en_US"), enUs, status);
     cache->get(LocaleCacheKey<UCTItem>("en_GB"), enGb, status);
     cache->get(LocaleCacheKey<UCTItem>("fr_FR"), frFr, status);
     cache->get(LocaleCacheKey<UCTItem>("fr"), fr, status);
-    cache->get(LocaleCacheKey<UCTItem>("en_GB"), enGb2, status);
+    cache->get(LocaleCacheKey<UCTItem>("en_GB"), enGb2, status); 
     SharedObject::clearPtr(enGb2);
     if (enGb != enUs) {
         errln("Expected en_GB and en_US to resolve to same object.");
@@ -322,16 +322,16 @@ void UnifiedCacheTest::TestBasic() {
     if (enGb == fr) {
         errln("Expected en_GB and fr to return different objects.");
     }
-    assertSuccess("", status);
+    assertSuccess("T1", status);
     // en_US, en_GB, en share one object; fr_FR and fr don't share.
     // 5 keys in all.
-    assertEquals("", baseCount + 5, cache->keyCount());
+    assertEquals("T2", baseCount + 5, cache->keyCount());
     SharedObject::clearPtr(enGb);
     cache->flush();
 
     // Only 2 unique values in the cache. flushing trims cache down
     // to this minimum size.
-    assertEquals("", baseCount + 2, cache->keyCount());
+    assertEquals("T3", baseCount + 2, cache->keyCount());
     SharedObject::clearPtr(enUs);
     SharedObject::clearPtr(en);
     cache->flush();
@@ -339,14 +339,14 @@ void UnifiedCacheTest::TestBasic() {
     // the "en" object, so it gets flushed and the keys that refer to it
     // get removed from the cache. Now we have just one unique value, fr, in
     // the cache
-    assertEquals("", baseCount + 1, cache->keyCount());
+    assertEquals("T4", baseCount + 1, cache->keyCount());
     SharedObject::clearPtr(fr);
     cache->flush();
-    assertEquals("", baseCount + 1, cache->keyCount());
+    assertEquals("T5", baseCount + 1, cache->keyCount());
     SharedObject::clearPtr(frFr);
     cache->flush();
-    assertEquals("", baseCount + 0, cache->keyCount());
-    assertSuccess("", status);
+    assertEquals("T6", baseCount + 0, cache->keyCount());
+    assertSuccess("T7", status);
 }
 
 void UnifiedCacheTest::TestError() {
@@ -355,9 +355,9 @@ void UnifiedCacheTest::TestError() {
     assertSuccess("", status);
     cache->flush();
     int32_t baseCount = cache->keyCount();
-    const UCTItem *zh = NULL;
-    const UCTItem *zhTw = NULL;
-    const UCTItem *zhHk = NULL;
+    const UCTItem *zh = nullptr;
+    const UCTItem *zhTw = nullptr;
+    const UCTItem *zhHk = nullptr;
 
     status = U_ZERO_ERROR;
     cache->get(LocaleCacheKey<UCTItem>("zh"), zh, status);
